searchData={"content_type":"text/markdown","items":[{"doc":"A module to trace Xandra queries with OpenTelemetry.\n\nThis library uses [Telemetry](https://github.com/beam-telemetry/telemetry) to\ncreate OpenTelemetry Spans for Xandra queries.","ref":"OpenTelemetryXandra.html","title":"OpenTelemetryXandra","type":"module"},{"doc":"See `attach/1`.","ref":"OpenTelemetryXandra.html#module-usage","title":"Usage - OpenTelemetryXandra","type":"module"},{"doc":"This library follows the OpenTelemetry Semantic Conventions for naming, according to:\n\n  * [The Cassandra conventions](https://opentelemetry.io/docs/specs/semconv/database/cassandra/)\n  * [The DB conventions](https://opentelemetry.io/docs/specs/semconv/database/database-spans/)","ref":"OpenTelemetryXandra.html#module-resources","title":"Resources - OpenTelemetryXandra","type":"module"},{"doc":"Attaches a Telemetry handler that records OTel spans for Xandra queries.","ref":"OpenTelemetryXandra.html#attach/1","title":"OpenTelemetryXandra.attach/1","type":"function"},{"doc":"Call this function in your application's `c:Application.start/2` callback:\n\n    def start(_type, _args) do\n      children = [\n        # ...\n      ]\n\n      OpenTelemetryXandra.attach()\n\n      Supervisor.start_link(children, strategy: :one_for_one)\n    end","ref":"OpenTelemetryXandra.html#attach/1-usage","title":"Usage - OpenTelemetryXandra.attach/1","type":"function"},{"doc":"* `:query_parser` - a function that takes a query (as a string) and should\n    return a DB operation string that will be used in the span name. For example,\n    for a query like `INSERT INTO users (id, name) VALUES (1, 'Alice')`, the\n    operation parser could return `INSERT`. The default operation parser\n    just takes the first word of the (whitespace-trimmed) query.\n\n  * `:statement` - it can be a boolean, where `true` means that the `db.statement`\n    span attribute gets filled with the query statement. If `false`, the attribute\n    doesn't get set. It can also be a function of type `t:statement_fun/0`: if it\n    returns `{:ok, statement}` then `db.statement` gets set to `statement`, while\n    if it returns `:error` then `db.statement` doesn't get set.\n\n> #### Sensitive Information {: .error}\n>\n> Xandra does not sanitize the query that this library captures. Whatever string\n> you pass to `Xandra.execute/4` and other functions gets used for the `:statement`\n> option.","ref":"OpenTelemetryXandra.html#attach/1-options","title":"Options - OpenTelemetryXandra.attach/1","type":"function"},{"doc":"The type for a function that parses a query and returns the operation, database, and table.\n\nSee `attach/1` for more information.","ref":"OpenTelemetryXandra.html#t:query_parser_fun/0","title":"OpenTelemetryXandra.query_parser_fun/0","type":"type"},{"doc":"Thet type for a function that returns the statement to be used in the span.\n\nSee `attach/1` for more information.","ref":"OpenTelemetryXandra.html#t:statement_fun/0","title":"OpenTelemetryXandra.statement_fun/0","type":"type"},{"doc":"# OpenTelemetryXandra\n\nThis library uses [Telemetry](https://github.com/beam-telemetry/telemetry/) events to create OpenTelemetry Spans for [Xandra](https://github.com/whatyouhide/xandra) queries.","ref":"readme.html","title":"OpenTelemetryXandra","type":"extras"},{"doc":"Add `opentelemetry_xandra` to your list of dependencies in `mix.exs`:\n\n```elixir\ndefp deps do\n  [\n    # Other opentelemetry_* deps...,\n    {:opentelemetry_xandra, \"~> 0.1\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - OpenTelemetryXandra","type":"extras"},{"doc":"| OpenTelemetryXandra Version | OpenTelemetry Version |\n| :-------------------------- | :-------------------- |\n| v0.1.0                      | v1.0.0                |","ref":"readme.html#compatibility-matrix","title":"Compatibility Matrix - OpenTelemetryXandra","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}